@@ -1,23 +1,6 @@
-/*
- * Copyright (C) 2019 ~ 2019 Deepin Technology Co., Ltd.
- *
- * Author:     LZ <zhou.lu@archermind.com>
- *
- * Maintainer: LZ <zhou.lu@archermind.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2019 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #ifndef LOGCOLLECTORMAIN_H
 #define LOGCOLLECTORMAIN_H
@@ -31,6 +14,7 @@
 #include <DSplitter>
 #include <DTreeView>
 #include <DSettings>
+#include <qsettingbackend.h>
 
 #include <QHBoxLayout>
 #include <QShortcut>
@@ -110,6 +94,8 @@ private:
     DIconButton *m_refreshBtn {nullptr};
     DIconButton *m_exportAllBtn {nullptr};
     ExportProgressDlg *m_exportDlg {nullptr};
+
+    QSettingBackend  *m_backend {nullptr};
 };
 
 #endif // LOGCOLLECTORMAIN_H
