@@ -1,4 +1,4 @@
-// SPDX-FileCopyrightText: 2019 - 2022 UnionTech Software Technology Co., Ltd.
+// SPDX-FileCopyrightText: 2019 - 2023 UnionTech Software Technology Co., Ltd.
 //
 // SPDX-License-Identifier: GPL-3.0-or-later
 
@@ -69,6 +69,8 @@ void logDetailInfoWidget::cleanText()
     m_nameLabel->hide();
     m_event->hide();
     m_eventLabel->hide();
+
+    m_errorLabel->hide();
 }
 
 /**
@@ -161,6 +163,14 @@ void logDetailInfoWidget::initUI()
     m_nameLabel = new DLabel(DApplication::translate("Label", "Username:"), this);  // add by Airy
     DFontSizeManager::instance()->bind(m_nameLabel, DFontSizeManager::T7);
 
+    m_errorLabel = new DLabel("", this);
+    m_errorLabel->setMinimumWidth(70);
+    m_errorLabel->setMinimumHeight(20);
+    DFontSizeManager::instance()->bind(m_userLabel, DFontSizeManager::T7);
+    pa = DApplicationHelper::instance()->palette(m_errorLabel);
+    // pa.setBrush(DPalette::WindowText, QColor(85,85,85,0.40));
+    pa.setBrush(DPalette::WindowText, pa.color(DPalette::PlaceholderText));
+    DApplicationHelper::instance()->setPalette(m_errorLabel, pa);
 
     m_hline = new DHorizontalLine;
 
@@ -175,7 +185,7 @@ void logDetailInfoWidget::initUI()
 
     cleanText();
 
-    QVBoxLayout *v = new QVBoxLayout(this);
+    m_bottomLayer = new QVBoxLayout(this);
 
     QHBoxLayout *h1 = new QHBoxLayout(this);
     h1->addWidget(m_daemonName);
@@ -224,15 +234,16 @@ void logDetailInfoWidget::initUI()
     h2->addWidget(m_level);
     h2->setSpacing(20);
 
-    v->addLayout(h1);
-    v->addLayout(h2);
-    v->addWidget(m_hline);
-    v->addWidget(m_textBrowser, 3);
+    m_bottomLayer->addLayout(h1);
+    m_bottomLayer->addLayout(h2);
+    m_bottomLayer->addWidget(m_hline);
+    m_bottomLayer->addWidget(m_textBrowser, 3);
+    m_bottomLayer->addWidget(m_errorLabel, 0, Qt::AlignCenter);
 
-    v->setContentsMargins(20, 10, 20, 0);
-    v->setSpacing(4);
+    m_bottomLayer->setContentsMargins(20, 10, 20, 0);
+    m_bottomLayer->setSpacing(4);
 
-    this->setLayout(v);
+    this->setLayout(m_bottomLayer);
 }
 
 void logDetailInfoWidget::setTextCustomSize(QWidget *w)
@@ -296,6 +307,8 @@ void logDetailInfoWidget::fillDetailInfo(QString deamonName, QString usrName, QS
                                          QString status, QString action, QString uname,
                                          QString event)
 {
+    m_hline->show();
+    m_errorLabel->hide();
     if (deamonName.isEmpty()) {
         m_daemonName->hide();
     } else {
@@ -378,7 +391,41 @@ void logDetailInfoWidget::fillDetailInfo(QString deamonName, QString usrName, QS
     }
     // end
 
+    m_bottomLayer->setContentsMargins(20, 10, 20, 0);
     m_textBrowser->setText(msg);
+    m_textBrowser->show();
+}
+
+void logDetailInfoWidget::fillOOCDetailInfo(const QString &data, const int error)
+{
+    m_daemonName->hide();
+    m_dateTime->hide();
+    m_userName->hide();
+    m_pid->hide();
+    m_action->hide();
+    m_status->hide();
+    m_name->hide();
+    m_event->hide();
+
+    m_hline->hide();
+
+    m_userLabel->hide();
+    m_pidLabel->hide();
+    m_statusLabel->hide();
+    m_actionLabel->hide();
+    m_nameLabel->hide();
+    m_eventLabel->hide();
+
+    m_bottomLayer->setContentsMargins(20, 10, 0, 0);
+    if (error == 0) {
+        m_textBrowser->setText(data);
+        m_textBrowser->show();
+        m_errorLabel->hide();
+    } else {
+        m_textBrowser->hide();
+        m_errorLabel->show();
+        m_errorLabel->setText(data);
+    }
 }
 
 /**
@@ -388,7 +435,7 @@ void logDetailInfoWidget::fillDetailInfo(QString deamonName, QString usrName, QS
  * @param name 应用日志的应用名称
  */
 void logDetailInfoWidget::slot_DetailInfo(const QModelIndex &index, QStandardItemModel *pModel,
-                                          QString name)
+                                          const QString &data, const int error)
 {
     cleanText();
 
@@ -432,7 +479,7 @@ void logDetailInfoWidget::slot_DetailInfo(const QModelIndex &index, QStandardIte
                        index.siblingAtColumn(2).data().toString(), index,
                        index.siblingAtColumn(3).data().toString());
     } else if (dataStr.contains(APP_TABLE_DATA)) {
-        fillDetailInfo(name, hostname, "", index.siblingAtColumn(1).data().toString(), index,
+        fillDetailInfo(data, hostname, "", index.siblingAtColumn(1).data().toString(), index,
                        index.siblingAtColumn(3).data(Qt::UserRole + 99).toString());
     } else if (dataStr.contains(LAST_TABLE_DATA)) {
         //        fillDetailInfo("Event", m_pModel->item(index.row(), 0)->text(), "",
@@ -469,5 +516,7 @@ void logDetailInfoWidget::slot_DetailInfo(const QModelIndex &index, QStandardIte
     } else if (dataStr.contains(DMESG_TABLE_DATA)) {
         fillDetailInfo("kernel", hostname, "", index.siblingAtColumn(1).data().toString(), index,
                        index.siblingAtColumn(2).data().toString());
+    } else if (dataStr.contains(OOC_TABLE_DATA)) {
+        fillOOCDetailInfo(data, error);
     }
 }
