@@ -50,7 +50,7 @@ QString Utils::getQssContent(const QString &filePath)
 QString Utils::getConfigPath()
 {
     QDir dir(QDir(QStandardPaths::standardLocations(QStandardPaths::ConfigLocation).first())
-                 .filePath(qApp->organizationName()));
+             .filePath(qApp->organizationName()));
 
     return dir.filePath(qApp->applicationName());
 }
@@ -67,6 +67,17 @@ bool Utils::isFontMimeType(const QString &filePath)
     return false;
 }
 
+bool Utils::isTextFileType(const QString &filePath)
+{
+    QMimeDatabase db;
+    QMimeType mime = db.mimeTypeForFile(filePath);
+    //标准文本文件和空白无后缀文件均计入文本文件范围
+    if (mime.inherits("text/plain") || mime.inherits("application/x-zerosize")) {
+        return true;
+    }
+    return false;
+}
+
 QString Utils::suffixList()
 {
     return QString("Font Files (*.ttf *.ttc *.otf)");
@@ -127,7 +138,7 @@ QString Utils::loadFontFamilyFromFiles(const QString &fontFileName)
  * @param iReplaceStr要替换的字符串
  * @return 替换过的字符串
  */
-QByteArray Utils::replaceEmptyByteArray(QByteArray &iReplaceStr)
+QByteArray Utils::replaceEmptyByteArray(const QByteArray &iReplaceStr)
 {
     QByteArray byteOutput = iReplaceStr;
     //\u0000是空字符，\x01是标题开始，出现于系统日志部分进程进程名称最后一个字符，不替换英文情况下显示错误
@@ -251,3 +262,22 @@ bool Utils::checkAuthorization(const QString &actionId, qint64 applicationPid)
                                                            Authority::AllowUserInteraction);
     return result == Authority::Yes ? true : false;
 }
+
+QString Utils::osVersion()
+{
+    QProcess *unlock = new QProcess;
+    unlock->start("lsb_release", {"-r"});
+    unlock->waitForFinished();
+    auto output = unlock->readAllStandardOutput();
+    auto str = QString::fromUtf8(output);
+    QRegExp re("\t.+\n");
+    QString osVerStr;
+    if (re.indexIn(str) > -1) {
+        auto result = re.cap(0);
+        osVerStr = result.remove(0, 1).remove(result.size() - 1, 1);
+        qInfo() << "lsb_release -r:" << output;
+        qInfo() << "OS version:" << osVerStr;
+    }
+    unlock->deleteLater();
+    return osVerStr;
+}
