@@ -32,10 +32,11 @@ public:
     static QString getQssContent(const QString &filePath);
     static QString getConfigPath();
     static bool isFontMimeType(const QString &filePath);
+    static bool isTextFileType(const QString &filePath);
     static QString suffixList();
     static QPixmap renderSVG(const QString &filePath, const QSize &size);
     static QString loadFontFamilyFromFiles(const QString &fontFileName);
-    static QByteArray replaceEmptyByteArray(QByteArray &iReplaceStr);
+    static QByteArray replaceEmptyByteArray(const QByteArray &iReplaceStr);
     static CommandErrorType isErroCommand(const QString &str);
     static bool checkAndDeleteDir(const QString &iFilePath);
     static bool deleteDir(const QString &iFilePath);
@@ -46,6 +47,8 @@ public:
     static QString mkMutiDir(const QString &path);
     //授权框
     static bool checkAuthorization(const QString &actionId, qint64 applicationPid);
+    //系统版本号
+    static QString osVersion();
 };
 
 #endif
