@@ -12,8 +12,9 @@
 #include <QDBusConnection>
 #include <QDBusMessage>
 #include <QDBusConnectionInterface>
+#include <QStandardPaths>
 
-const QStringList ValidInvokerExePathList1 = {"/usr/bin/deepin-log-viewer"};
+//const QStringList ValidInvokerExePathList1 = QStandardPaths::locateAll(QStandardPaths::ApplicationsLocation, "deepin-log-viewer");
 
 LogViewerService::LogViewerService(QObject *parent)
     : QObject(parent)
@@ -40,10 +41,20 @@ LogViewerService::~LogViewerService()
  */
 QString LogViewerService::readLog(const QString &filePath)
 {
-    //增加服务黑名单，只允许通过提权接口读取/var/log下，家目录下和临时目录下的文件
-    if ((!filePath.startsWith("/var/log/") && !filePath.startsWith("/tmp") && !filePath.startsWith("/home")) || filePath.contains("..") || !isValidInvoker())  {
+    if(!isValidInvoker()) {
         return " ";
     }
+
+    //增加服务黑名单，只允许通过提权接口读取/var/log下，家目录下和临时目录下的文件
+    //部分设备是直接从root账户进入，因此还需要监控/root目录
+    if ((!filePath.startsWith("/var/log/") &&
+         !filePath.startsWith("/tmp") &&
+         !filePath.startsWith("/home") &&
+         !filePath.startsWith("/root")) ||
+         filePath.contains(".."))  {
+        return " ";
+    }
+
     m_process.start("cat", QStringList() << filePath);
     m_process.waitForFinished(-1);
     QByteArray byte = m_process.readAllStandardOutput();
@@ -196,6 +207,67 @@ QStringList LogViewerService::getFileInfo(const QString &file, bool unzip)
     return fileNamePath;
 }
 
+/*!
+ * \~chinese \brief LogViewerService::getOtherFileInfo 获取其他日志文件的路径
+ * \~chinese \param file 日志文件的类型
+ * \~chinese \return 所有日志文件路径列表
+ */
+QStringList LogViewerService::getOtherFileInfo(const QString &file, bool unzip)
+{
+    int fileNum = 0;
+    if (tmpDir.isValid()) {
+        tmpDirPath = tmpDir.path();
+    }
+    QStringList fileNamePath;
+    QString nameFilter;
+    QDir dir;
+    QFileInfo appFileInfo(file);
+    QFileInfoList fileList;
+    //判断路径是否存在
+    if (!appFileInfo.exists()) {
+        qWarning() << "it is not true path";
+        return QStringList();
+    }
+    //如果是文件
+    if (appFileInfo.isFile()) {
+        QString appDir = appFileInfo.absolutePath();
+        nameFilter = appFileInfo.fileName();
+        dir.setPath(appDir);
+        dir.setNameFilters(QStringList() << nameFilter + "*"); //设置过滤
+    } else if (appFileInfo.isDir()) {
+        //如果是目录
+        dir.setPath(file);
+    }
+
+    dir.setFilter(QDir::Files | QDir::NoSymLinks | QDir::Hidden); //实现对文件的过滤
+    dir.setSorting(QDir::Time);
+    fileList = dir.entryInfoList();
+
+    for (int i = 0; i < fileList.count(); i++) {
+        if (QString::compare(fileList[i].suffix(), "gz", Qt::CaseInsensitive) == 0 && unzip) {
+            //                qDebug() << tmpDirPath;
+            QProcess m_process;
+
+            QString command = "gunzip";
+            QStringList args;
+            args.append("-c");
+            //                qDebug() << fileList[i].absoluteFilePath();
+            args.append(fileList[i].absoluteFilePath());
+            m_process.setStandardOutputFile(tmpDirPath + "/" + QString::number(fileNum) + ".txt");
+            m_process.start(command, args);
+            m_process.waitForFinished(-1);
+            //                qDebug() << m_process.readAll();
+            fileNamePath.append(tmpDirPath + "/" + QString::number(fileNum) + ".txt");
+            fileNum++;
+        }
+        else {
+            fileNamePath.append(fileList[i].absoluteFilePath());
+        }
+    }
+    //       qInfo()<<fileNamePath.count()<<fileNamePath<<"******************************";
+    return fileNamePath;
+}
+
 bool LogViewerService::exportLog(const QString &outDir, const QString &in, bool isFile)
 {
     if(!isValidInvoker()) { //非法调用
@@ -265,9 +337,14 @@ bool LogViewerService::isValidInvoker()
     }
 
     //是否存在于可调用者名单中
+    QStringList ValidInvokerExePathList;
     QString invokerPath = f.canonicalFilePath();
+    QStringList findPaths;//合法调用者查找目录列表
+    findPaths << "/usr/bin";
+    ValidInvokerExePathList << QStandardPaths::findExecutable("deepin-log-viewer", findPaths);
+
     if (valid)
-        valid = ValidInvokerExePathList1.contains(invokerPath);
+        valid = ValidInvokerExePathList.contains(invokerPath);
 
     //非法调用
     if (!valid) {
