@@ -1,19 +1,6 @@
-/*
-* Copyright (C) 2019 ~ 2020 UnionTech Software Technology Co.,Ltd
-*
-* Author:     linxun <linxun@uniontech.com>
-* Maintainer:  linxun <linxun@uniontech.com>
-* This program is free software: you can redistribute it and/or modify
-* it under the terms of the GNU General Public License as published by
-* the Free Software Foundation, either version 3 of the License, or
-* any later version.
-* This program is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-* GNU General Public License for more details.
-* You should have received a copy of the GNU General Public License
-* along with this program.  If not, see <http://www.gnu.org/licenses/>.
-*/
+// SPDX-FileCopyrightText: 2019 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "dldbusinterface.h"
 
@@ -50,6 +37,8 @@ public:
 TEST_F(DlDbusinterface_UT, Compare_UT)
 {
     m_interface->exitCode();
+    m_interface->exportLog("path", "path1", false);
+    m_interface->getFileInfo("path", false);
     m_interface->quit();
     m_interface->readLog("Test");
 }
