@@ -4,7 +4,7 @@
 		<message>
 			<location filename="com.deepin.pkexec.logViewerTruncate!message" line="0"/>
 			<source>Authentication is required to clear the log</source>
-			<translation>Do wyczyszczenia dziennika wymagane jest uwierzytelnienie</translation>
+			<translation>Wymagane jest uwierzytelnienie do wyczyszczenia logów</translation>
 		</message>
 		<message>
 			<location filename="com.deepin.pkexec.logViewerTruncate!description" line="0"/>
